/* granite-7.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __LIB_GRANITE_7_H__
#define __LIB_GRANITE_7_H__

#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <glib-object.h>
#include <gdk/gdk.h>
#include <gio/gio.h>
#include <float.h>
#include <math.h>
#include <gee.h>
#include <gtk/gtk.h>
#include <pango/pango.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif
#define GRANITE_STYLE_CLASS_ACCENT "accent"
#define GRANITE_STYLE_CLASS_BACK_BUTTON "back-button"
#define GRANITE_STYLE_CLASS_BACKGROUND "background"
#define GRANITE_STYLE_CLASS_BADGE "badge"
#define GRANITE_STYLE_CLASS_CARD "card"
#define GRANITE_STYLE_CLASS_CHECKERBOARD "checkerboard"
#define GRANITE_STYLE_CLASS_CIRCULAR "circular"
#define GRANITE_STYLE_CLASS_COLOR_BUTTON "color-button"
#define GRANITE_STYLE_CLASS_DEFAULT_DECORATION "default-decoration"
#define GRANITE_STYLE_CLASS_DESTRUCTIVE_ACTION "destructive-action"
#define GRANITE_STYLE_CLASS_DIALOG_CONTENT_AREA "dialog-content-area"
#define GRANITE_STYLE_CLASS_FRAME "frame"
#define GRANITE_STYLE_CLASS_H1_LABEL "title-1"
#define GRANITE_STYLE_CLASS_H2_LABEL "title-2"
#define GRANITE_STYLE_CLASS_H3_LABEL "title-3"
#define GRANITE_STYLE_CLASS_H4_LABEL "title-4"
#define GRANITE_STYLE_CLASS_KEYCAP "keycap"
#define GRANITE_STYLE_CLASS_LARGE_ICONS "large-icons"
#define GRANITE_STYLE_CLASS_MODE_SWITCH "mode-switch"
#define GRANITE_STYLE_CLASS_OSD "osd"
#define GRANITE_STYLE_CLASS_ROUNDED "rounded"
#define GRANITE_STYLE_CLASS_SIDEBAR "sidebar"
#define GRANITE_STYLE_CLASS_SMALL_LABEL "small-label"
#define GRANITE_STYLE_CLASS_SUCCESS "success"
#define GRANITE_STYLE_CLASS_TERMINAL "terminal"
#define GRANITE_STYLE_CLASS_TITLE_LABEL "title"
#define GRANITE_STYLE_CLASS_WARMTH "warmth"
#define GRANITE_STYLE_CLASS_TEMPERATURE "temperature"
#define GRANITE_STYLE_CLASS_LINKED "linked"
#define GRANITE_STYLE_CLASS_MENU "menu"
#define GRANITE_STYLE_CLASS_MENUITEM "menuitem"
#define GRANITE_STYLE_CLASS_DIM_LABEL "dim-label"
#define GRANITE_STYLE_CLASS_ERROR "error"
#define GRANITE_STYLE_CLASS_FLAT "flat"
#define GRANITE_STYLE_CLASS_MESSAGE_DIALOG "message"
#define GRANITE_STYLE_CLASS_RICH_LIST "rich-list"
#define GRANITE_STYLE_CLASS_SUGGESTED_ACTION "suggested-action"
#define GRANITE_STYLE_CLASS_VIEW "view"
#define GRANITE_STYLE_CLASS_WARNING "warning"
#define GRANITE_TRANSITION_DURATION_CLOSE 200
#define GRANITE_TRANSITION_DURATION_IN_PLACE 100
#define GRANITE_TRANSITION_DURATION_OPEN 250
#define GRANITE_CSS_CLASS_ACCENT "accent"
#define GRANITE_CSS_CLASS_CARD "card"
#define GRANITE_CSS_CLASS_CHECKERBOARD "checkerboard"
#define GRANITE_CSS_CLASS_CIRCULAR "circular"
#define GRANITE_CSS_CLASS_DESTRUCTIVE "destructive"
#define GRANITE_CSS_CLASS_DIM "dim-label"
#define GRANITE_CSS_CLASS_ERROR "error"
#define GRANITE_CSS_CLASS_NUMERIC "numeric"
#define GRANITE_CSS_CLASS_SMALL "small-label"
#define GRANITE_CSS_CLASS_SUGGESTED "suggested"
#define GRANITE_CSS_CLASS_SUCCESS "success"
#define GRANITE_CSS_CLASS_WARNING "warning"
#define GRANITE_CSS_CLASS_MONOSPACE "monospace"
#define GRANITE_SETTINGS_URI_LOCATION "settings://privacy/location"
#define GRANITE_SETTINGS_URI_ONLINE_ACCOUNTS "settings://accounts/online"
#define GRANITE_SETTINGS_URI_NETWORK "settings://network"
#define GRANITE_SETTINGS_URI_PERMISSIONS "settings://applications/permissions"
#define GRANITE_SETTINGS_URI_NOTIFICATIONS "settings://notifications"
#define GRANITE_SETTINGS_URI_SOUND_INPUT "settings://sound/input"
#define GRANITE_SETTINGS_URI_SHORTCUTS "settings://input/keyboard/shortcuts/custom"
#define GRANITE_TOOLTIP_SECONDARY_TEXT_MARKUP "<span weight=\"600\" size=\"smaller\" alpha=\"75%\">%s</span>"

#define GRANITE_TYPE_STYLE_MANAGER (granite_style_manager_get_type ())
#define GRANITE_STYLE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_STYLE_MANAGER, GraniteStyleManager))
#define GRANITE_STYLE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_STYLE_MANAGER, GraniteStyleManagerClass))
#define GRANITE_IS_STYLE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_STYLE_MANAGER))
#define GRANITE_IS_STYLE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_STYLE_MANAGER))
#define GRANITE_STYLE_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_STYLE_MANAGER, GraniteStyleManagerClass))

typedef struct _GraniteStyleManager GraniteStyleManager;
typedef struct _GraniteStyleManagerClass GraniteStyleManagerClass;
typedef struct _GraniteStyleManagerPrivate GraniteStyleManagerPrivate;
typedef enum  {
	GRANITE_SETTINGS_COLOR_SCHEME_NO_PREFERENCE,
	GRANITE_SETTINGS_COLOR_SCHEME_DARK,
	GRANITE_SETTINGS_COLOR_SCHEME_LIGHT
} GraniteSettingsColorScheme;

#define GRANITE_SETTINGS_TYPE_COLOR_SCHEME (granite_settings_color_scheme_get_type ())

#define GRANITE_SERVICES_TYPE_CONTRACT (granite_services_contract_get_type ())
#define GRANITE_SERVICES_CONTRACT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_SERVICES_TYPE_CONTRACT, GraniteServicesContract))
#define GRANITE_SERVICES_IS_CONTRACT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_SERVICES_TYPE_CONTRACT))
#define GRANITE_SERVICES_CONTRACT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GRANITE_SERVICES_TYPE_CONTRACT, GraniteServicesContractIface))

typedef struct _GraniteServicesContract GraniteServicesContract;
typedef struct _GraniteServicesContractIface GraniteServicesContractIface;

#define GRANITE_SERVICES_TYPE_CONTRACTOR_ERROR (granite_services_contractor_error_get_type ())

#define GRANITE_SERVICES_TYPE_CONTRACTOR_PROXY (granite_services_contractor_proxy_get_type ())
#define GRANITE_SERVICES_CONTRACTOR_PROXY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_SERVICES_TYPE_CONTRACTOR_PROXY, GraniteServicesContractorProxy))
#define GRANITE_SERVICES_CONTRACTOR_PROXY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_SERVICES_TYPE_CONTRACTOR_PROXY, GraniteServicesContractorProxyClass))
#define GRANITE_SERVICES_IS_CONTRACTOR_PROXY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_SERVICES_TYPE_CONTRACTOR_PROXY))
#define GRANITE_SERVICES_IS_CONTRACTOR_PROXY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_SERVICES_TYPE_CONTRACTOR_PROXY))
#define GRANITE_SERVICES_CONTRACTOR_PROXY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_SERVICES_TYPE_CONTRACTOR_PROXY, GraniteServicesContractorProxyClass))

typedef struct _GraniteServicesContractorProxy GraniteServicesContractorProxy;
typedef struct _GraniteServicesContractorProxyClass GraniteServicesContractorProxyClass;
typedef struct _GraniteServicesContractorProxyPrivate GraniteServicesContractorProxyPrivate;

#define GRANITE_SERVICES_TYPE_SETTINGS_SERIALIZABLE (granite_services_settings_serializable_get_type ())
#define GRANITE_SERVICES_SETTINGS_SERIALIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_SERVICES_TYPE_SETTINGS_SERIALIZABLE, GraniteServicesSettingsSerializable))
#define GRANITE_SERVICES_IS_SETTINGS_SERIALIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_SERVICES_TYPE_SETTINGS_SERIALIZABLE))
#define GRANITE_SERVICES_SETTINGS_SERIALIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GRANITE_SERVICES_TYPE_SETTINGS_SERIALIZABLE, GraniteServicesSettingsSerializableIface))

typedef struct _GraniteServicesSettingsSerializable GraniteServicesSettingsSerializable;
typedef struct _GraniteServicesSettingsSerializableIface GraniteServicesSettingsSerializableIface;

#define GRANITE_SERVICES_TYPE_SYSTEM (granite_services_system_get_type ())
#define GRANITE_SERVICES_SYSTEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_SERVICES_TYPE_SYSTEM, GraniteServicesSystem))
#define GRANITE_SERVICES_SYSTEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_SERVICES_TYPE_SYSTEM, GraniteServicesSystemClass))
#define GRANITE_SERVICES_IS_SYSTEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_SERVICES_TYPE_SYSTEM))
#define GRANITE_SERVICES_IS_SYSTEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_SERVICES_TYPE_SYSTEM))
#define GRANITE_SERVICES_SYSTEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_SERVICES_TYPE_SYSTEM, GraniteServicesSystemClass))

typedef struct _GraniteServicesSystem GraniteServicesSystem;
typedef struct _GraniteServicesSystemClass GraniteServicesSystemClass;
typedef struct _GraniteServicesSystemPrivate GraniteServicesSystemPrivate;

#define GRANITE_TYPE_SETTINGS_PAGE (granite_settings_page_get_type ())
#define GRANITE_SETTINGS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_SETTINGS_PAGE, GraniteSettingsPage))
#define GRANITE_SETTINGS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_SETTINGS_PAGE, GraniteSettingsPageClass))
#define GRANITE_IS_SETTINGS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_SETTINGS_PAGE))
#define GRANITE_IS_SETTINGS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_SETTINGS_PAGE))
#define GRANITE_SETTINGS_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_SETTINGS_PAGE, GraniteSettingsPageClass))

typedef struct _GraniteSettingsPage GraniteSettingsPage;
typedef struct _GraniteSettingsPageClass GraniteSettingsPageClass;
typedef struct _GraniteSettingsPagePrivate GraniteSettingsPagePrivate;
typedef enum  {
	GRANITE_SETTINGS_PAGE_STATUS_TYPE_ERROR,
	GRANITE_SETTINGS_PAGE_STATUS_TYPE_OFFLINE,
	GRANITE_SETTINGS_PAGE_STATUS_TYPE_SUCCESS,
	GRANITE_SETTINGS_PAGE_STATUS_TYPE_WARNING,
	GRANITE_SETTINGS_PAGE_STATUS_TYPE_NONE
} GraniteSettingsPageStatusType;

#define GRANITE_SETTINGS_PAGE_TYPE_STATUS_TYPE (granite_settings_page_status_type_get_type ())

#define GRANITE_TYPE_SIMPLE_SETTINGS_PAGE (granite_simple_settings_page_get_type ())
#define GRANITE_SIMPLE_SETTINGS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_SIMPLE_SETTINGS_PAGE, GraniteSimpleSettingsPage))
#define GRANITE_SIMPLE_SETTINGS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_SIMPLE_SETTINGS_PAGE, GraniteSimpleSettingsPageClass))
#define GRANITE_IS_SIMPLE_SETTINGS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_SIMPLE_SETTINGS_PAGE))
#define GRANITE_IS_SIMPLE_SETTINGS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_SIMPLE_SETTINGS_PAGE))
#define GRANITE_SIMPLE_SETTINGS_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_SIMPLE_SETTINGS_PAGE, GraniteSimpleSettingsPageClass))

typedef struct _GraniteSimpleSettingsPage GraniteSimpleSettingsPage;
typedef struct _GraniteSimpleSettingsPageClass GraniteSimpleSettingsPageClass;
typedef struct _GraniteSimpleSettingsPagePrivate GraniteSimpleSettingsPagePrivate;

#define GRANITE_TYPE_ACCEL_LABEL (granite_accel_label_get_type ())
#define GRANITE_ACCEL_LABEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_ACCEL_LABEL, GraniteAccelLabel))
#define GRANITE_ACCEL_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_ACCEL_LABEL, GraniteAccelLabelClass))
#define GRANITE_IS_ACCEL_LABEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_ACCEL_LABEL))
#define GRANITE_IS_ACCEL_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_ACCEL_LABEL))
#define GRANITE_ACCEL_LABEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_ACCEL_LABEL, GraniteAccelLabelClass))

typedef struct _GraniteAccelLabel GraniteAccelLabel;
typedef struct _GraniteAccelLabelClass GraniteAccelLabelClass;
typedef struct _GraniteAccelLabelPrivate GraniteAccelLabelPrivate;

#define GRANITE_TYPE_BACK_BUTTON (granite_back_button_get_type ())
#define GRANITE_BACK_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_BACK_BUTTON, GraniteBackButton))
#define GRANITE_BACK_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_BACK_BUTTON, GraniteBackButtonClass))
#define GRANITE_IS_BACK_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_BACK_BUTTON))
#define GRANITE_IS_BACK_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_BACK_BUTTON))
#define GRANITE_BACK_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_BACK_BUTTON, GraniteBackButtonClass))

typedef struct _GraniteBackButton GraniteBackButton;
typedef struct _GraniteBackButtonClass GraniteBackButtonClass;
typedef struct _GraniteBackButtonPrivate GraniteBackButtonPrivate;

#define GRANITE_TYPE_BIN (granite_bin_get_type ())
#define GRANITE_BIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_BIN, GraniteBin))
#define GRANITE_BIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_BIN, GraniteBinClass))
#define GRANITE_IS_BIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_BIN))
#define GRANITE_IS_BIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_BIN))
#define GRANITE_BIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_BIN, GraniteBinClass))

typedef struct _GraniteBin GraniteBin;
typedef struct _GraniteBinClass GraniteBinClass;
typedef struct _GraniteBinPrivate GraniteBinPrivate;

#define GRANITE_TYPE_BOX (granite_box_get_type ())
#define GRANITE_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_BOX, GraniteBox))
#define GRANITE_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_BOX, GraniteBoxClass))
#define GRANITE_IS_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_BOX))
#define GRANITE_IS_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_BOX))
#define GRANITE_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_BOX, GraniteBoxClass))

typedef struct _GraniteBox GraniteBox;
typedef struct _GraniteBoxClass GraniteBoxClass;
typedef struct _GraniteBoxPrivate GraniteBoxPrivate;
typedef enum  {
	GRANITE_BOX_SPACING_NONE,
	GRANITE_BOX_SPACING_HALF,
	GRANITE_BOX_SPACING_SINGLE,
	GRANITE_BOX_SPACING_DOUBLE,
	GRANITE_BOX_SPACING_LINKED
} GraniteBoxSpacing;

#define GRANITE_BOX_TYPE_SPACING (granite_box_spacing_get_type ())

#define GRANITE_TYPE_DATE_PICKER (granite_date_picker_get_type ())
#define GRANITE_DATE_PICKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_DATE_PICKER, GraniteDatePicker))
#define GRANITE_DATE_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_DATE_PICKER, GraniteDatePickerClass))
#define GRANITE_IS_DATE_PICKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_DATE_PICKER))
#define GRANITE_IS_DATE_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_DATE_PICKER))
#define GRANITE_DATE_PICKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_DATE_PICKER, GraniteDatePickerClass))

typedef struct _GraniteDatePicker GraniteDatePicker;
typedef struct _GraniteDatePickerClass GraniteDatePickerClass;
typedef struct _GraniteDatePickerPrivate GraniteDatePickerPrivate;

#define GRANITE_TYPE_DIALOG (granite_dialog_get_type ())
#define GRANITE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_DIALOG, GraniteDialog))
#define GRANITE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_DIALOG, GraniteDialogClass))
#define GRANITE_IS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_DIALOG))
#define GRANITE_IS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_DIALOG))
#define GRANITE_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_DIALOG, GraniteDialogClass))

typedef struct _GraniteDialog GraniteDialog;
typedef struct _GraniteDialogClass GraniteDialogClass;
typedef struct _GraniteDialogPrivate GraniteDialogPrivate;

#define GRANITE_TYPE_HEADER_LABEL (granite_header_label_get_type ())
#define GRANITE_HEADER_LABEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_HEADER_LABEL, GraniteHeaderLabel))
#define GRANITE_HEADER_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_HEADER_LABEL, GraniteHeaderLabelClass))
#define GRANITE_IS_HEADER_LABEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_HEADER_LABEL))
#define GRANITE_IS_HEADER_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_HEADER_LABEL))
#define GRANITE_HEADER_LABEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_HEADER_LABEL, GraniteHeaderLabelClass))

typedef struct _GraniteHeaderLabel GraniteHeaderLabel;
typedef struct _GraniteHeaderLabelClass GraniteHeaderLabelClass;
typedef struct _GraniteHeaderLabelPrivate GraniteHeaderLabelPrivate;
typedef enum  {
	GRANITE_HEADER_LABEL_SIZE_H1,
	GRANITE_HEADER_LABEL_SIZE_H2,
	GRANITE_HEADER_LABEL_SIZE_H3,
	GRANITE_HEADER_LABEL_SIZE_H4
} GraniteHeaderLabelSize;

#define GRANITE_HEADER_LABEL_TYPE_SIZE (granite_header_label_size_get_type ())

#define GRANITE_TYPE_HYPER_TEXT_VIEW (granite_hyper_text_view_get_type ())
#define GRANITE_HYPER_TEXT_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_HYPER_TEXT_VIEW, GraniteHyperTextView))
#define GRANITE_HYPER_TEXT_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_HYPER_TEXT_VIEW, GraniteHyperTextViewClass))
#define GRANITE_IS_HYPER_TEXT_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_HYPER_TEXT_VIEW))
#define GRANITE_IS_HYPER_TEXT_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_HYPER_TEXT_VIEW))
#define GRANITE_HYPER_TEXT_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_HYPER_TEXT_VIEW, GraniteHyperTextViewClass))

typedef struct _GraniteHyperTextView GraniteHyperTextView;
typedef struct _GraniteHyperTextViewClass GraniteHyperTextViewClass;
typedef struct _GraniteHyperTextViewPrivate GraniteHyperTextViewPrivate;

#define GRANITE_TYPE_LIST_ITEM (granite_list_item_get_type ())
#define GRANITE_LIST_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_LIST_ITEM, GraniteListItem))
#define GRANITE_LIST_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_LIST_ITEM, GraniteListItemClass))
#define GRANITE_IS_LIST_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_LIST_ITEM))
#define GRANITE_IS_LIST_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_LIST_ITEM))
#define GRANITE_LIST_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_LIST_ITEM, GraniteListItemClass))

typedef struct _GraniteListItem GraniteListItem;
typedef struct _GraniteListItemClass GraniteListItemClass;
typedef struct _GraniteListItemPrivate GraniteListItemPrivate;

#define GRANITE_TYPE_MESSAGE_DIALOG (granite_message_dialog_get_type ())
#define GRANITE_MESSAGE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_MESSAGE_DIALOG, GraniteMessageDialog))
#define GRANITE_MESSAGE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_MESSAGE_DIALOG, GraniteMessageDialogClass))
#define GRANITE_IS_MESSAGE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_MESSAGE_DIALOG))
#define GRANITE_IS_MESSAGE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_MESSAGE_DIALOG))
#define GRANITE_MESSAGE_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_MESSAGE_DIALOG, GraniteMessageDialogClass))

typedef struct _GraniteMessageDialog GraniteMessageDialog;
typedef struct _GraniteMessageDialogClass GraniteMessageDialogClass;
typedef struct _GraniteMessageDialogPrivate GraniteMessageDialogPrivate;

#define GRANITE_TYPE_MODE_SWITCH (granite_mode_switch_get_type ())
#define GRANITE_MODE_SWITCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_MODE_SWITCH, GraniteModeSwitch))
#define GRANITE_MODE_SWITCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_MODE_SWITCH, GraniteModeSwitchClass))
#define GRANITE_IS_MODE_SWITCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_MODE_SWITCH))
#define GRANITE_IS_MODE_SWITCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_MODE_SWITCH))
#define GRANITE_MODE_SWITCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_MODE_SWITCH, GraniteModeSwitchClass))

typedef struct _GraniteModeSwitch GraniteModeSwitch;
typedef struct _GraniteModeSwitchClass GraniteModeSwitchClass;
typedef struct _GraniteModeSwitchPrivate GraniteModeSwitchPrivate;

#define GRANITE_TYPE_OVERLAY_BAR (granite_overlay_bar_get_type ())
#define GRANITE_OVERLAY_BAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_OVERLAY_BAR, GraniteOverlayBar))
#define GRANITE_OVERLAY_BAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_OVERLAY_BAR, GraniteOverlayBarClass))
#define GRANITE_IS_OVERLAY_BAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_OVERLAY_BAR))
#define GRANITE_IS_OVERLAY_BAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_OVERLAY_BAR))
#define GRANITE_OVERLAY_BAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_OVERLAY_BAR, GraniteOverlayBarClass))

typedef struct _GraniteOverlayBar GraniteOverlayBar;
typedef struct _GraniteOverlayBarClass GraniteOverlayBarClass;
typedef struct _GraniteOverlayBarPrivate GraniteOverlayBarPrivate;

#define GRANITE_TYPE_PLACEHOLDER (granite_placeholder_get_type ())
#define GRANITE_PLACEHOLDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_PLACEHOLDER, GranitePlaceholder))
#define GRANITE_PLACEHOLDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_PLACEHOLDER, GranitePlaceholderClass))
#define GRANITE_IS_PLACEHOLDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_PLACEHOLDER))
#define GRANITE_IS_PLACEHOLDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_PLACEHOLDER))
#define GRANITE_PLACEHOLDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_PLACEHOLDER, GranitePlaceholderClass))

typedef struct _GranitePlaceholder GranitePlaceholder;
typedef struct _GranitePlaceholderClass GranitePlaceholderClass;
typedef struct _GranitePlaceholderPrivate GranitePlaceholderPrivate;

#define GRANITE_TYPE_SETTINGS_SIDEBAR (granite_settings_sidebar_get_type ())
#define GRANITE_SETTINGS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_SETTINGS_SIDEBAR, GraniteSettingsSidebar))
#define GRANITE_SETTINGS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_SETTINGS_SIDEBAR, GraniteSettingsSidebarClass))
#define GRANITE_IS_SETTINGS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_SETTINGS_SIDEBAR))
#define GRANITE_IS_SETTINGS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_SETTINGS_SIDEBAR))
#define GRANITE_SETTINGS_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_SETTINGS_SIDEBAR, GraniteSettingsSidebarClass))

typedef struct _GraniteSettingsSidebar GraniteSettingsSidebar;
typedef struct _GraniteSettingsSidebarClass GraniteSettingsSidebarClass;
typedef struct _GraniteSettingsSidebarPrivate GraniteSettingsSidebarPrivate;

#define GRANITE_TYPE_SETTINGS (granite_settings_get_type ())
#define GRANITE_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_SETTINGS, GraniteSettings))
#define GRANITE_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_SETTINGS, GraniteSettingsClass))
#define GRANITE_IS_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_SETTINGS))
#define GRANITE_IS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_SETTINGS))
#define GRANITE_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_SETTINGS, GraniteSettingsClass))

typedef struct _GraniteSettings GraniteSettings;
typedef struct _GraniteSettingsClass GraniteSettingsClass;
typedef struct _GraniteSettingsPrivate GraniteSettingsPrivate;

#define GRANITE_TYPE_SWITCH_MODEL_BUTTON (granite_switch_model_button_get_type ())
#define GRANITE_SWITCH_MODEL_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_SWITCH_MODEL_BUTTON, GraniteSwitchModelButton))
#define GRANITE_SWITCH_MODEL_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_SWITCH_MODEL_BUTTON, GraniteSwitchModelButtonClass))
#define GRANITE_IS_SWITCH_MODEL_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_SWITCH_MODEL_BUTTON))
#define GRANITE_IS_SWITCH_MODEL_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_SWITCH_MODEL_BUTTON))
#define GRANITE_SWITCH_MODEL_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_SWITCH_MODEL_BUTTON, GraniteSwitchModelButtonClass))

typedef struct _GraniteSwitchModelButton GraniteSwitchModelButton;
typedef struct _GraniteSwitchModelButtonClass GraniteSwitchModelButtonClass;
typedef struct _GraniteSwitchModelButtonPrivate GraniteSwitchModelButtonPrivate;

#define GRANITE_TYPE_TIME_PICKER (granite_time_picker_get_type ())
#define GRANITE_TIME_PICKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_TIME_PICKER, GraniteTimePicker))
#define GRANITE_TIME_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_TIME_PICKER, GraniteTimePickerClass))
#define GRANITE_IS_TIME_PICKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_TIME_PICKER))
#define GRANITE_IS_TIME_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_TIME_PICKER))
#define GRANITE_TIME_PICKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_TIME_PICKER, GraniteTimePickerClass))

typedef struct _GraniteTimePicker GraniteTimePicker;
typedef struct _GraniteTimePickerClass GraniteTimePickerClass;
typedef struct _GraniteTimePickerPrivate GraniteTimePickerPrivate;

#define GRANITE_TYPE_TOOL_BOX (granite_tool_box_get_type ())
#define GRANITE_TOOL_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_TOOL_BOX, GraniteToolBox))
#define GRANITE_TOOL_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_TOOL_BOX, GraniteToolBoxClass))
#define GRANITE_IS_TOOL_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_TOOL_BOX))
#define GRANITE_IS_TOOL_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_TOOL_BOX))
#define GRANITE_TOOL_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_TOOL_BOX, GraniteToolBoxClass))

typedef struct _GraniteToolBox GraniteToolBox;
typedef struct _GraniteToolBoxClass GraniteToolBoxClass;
typedef struct _GraniteToolBoxPrivate GraniteToolBoxPrivate;

#define GRANITE_TYPE_TOAST (granite_toast_get_type ())
#define GRANITE_TOAST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_TOAST, GraniteToast))
#define GRANITE_TOAST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_TOAST, GraniteToastClass))
#define GRANITE_IS_TOAST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_TOAST))
#define GRANITE_IS_TOAST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_TOAST))
#define GRANITE_TOAST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_TOAST, GraniteToastClass))

typedef struct _GraniteToast GraniteToast;
typedef struct _GraniteToastClass GraniteToastClass;
typedef struct _GraniteToastPrivate GraniteToastPrivate;
typedef enum  {
	GRANITE_TOAST_DISMISS_REASON_EXPIRED = 1,
	GRANITE_TOAST_DISMISS_REASON_CLOSED = 2,
	GRANITE_TOAST_DISMISS_REASON_WITHDRAWN = 3
} GraniteToastDismissReason;

#define GRANITE_TOAST_TYPE_DISMISS_REASON (granite_toast_dismiss_reason_get_type ())

#define GRANITE_TYPE_VALIDATED_ENTRY (granite_validated_entry_get_type ())
#define GRANITE_VALIDATED_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_VALIDATED_ENTRY, GraniteValidatedEntry))
#define GRANITE_VALIDATED_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_VALIDATED_ENTRY, GraniteValidatedEntryClass))
#define GRANITE_IS_VALIDATED_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_VALIDATED_ENTRY))
#define GRANITE_IS_VALIDATED_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_VALIDATED_ENTRY))
#define GRANITE_VALIDATED_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_VALIDATED_ENTRY, GraniteValidatedEntryClass))

typedef struct _GraniteValidatedEntry GraniteValidatedEntry;
typedef struct _GraniteValidatedEntryClass GraniteValidatedEntryClass;
typedef struct _GraniteValidatedEntryPrivate GraniteValidatedEntryPrivate;

struct _GraniteStyleManager {
	GObject parent_instance;
	GraniteStyleManagerPrivate * priv;
};

struct _GraniteStyleManagerClass {
	GObjectClass parent_class;
};

struct _GraniteServicesContractIface {
	GTypeInterface parent_iface;
	gchar* (*get_display_name) (GraniteServicesContract* self);
	gchar* (*get_description) (GraniteServicesContract* self);
	GIcon* (*get_icon) (GraniteServicesContract* self);
	void (*execute_with_file) (GraniteServicesContract* self, GFile* file, GError** error);
	void (*execute_with_files) (GraniteServicesContract* self, GFile** files, gint files_length1, GError** error);
};

typedef enum  {
	GRANITE_SERVICES_CONTRACTOR_ERROR_SERVICE_NOT_AVAILABLE
} GraniteServicesContractorError;
#define GRANITE_SERVICES_CONTRACTOR_ERROR granite_services_contractor_error_quark ()

struct _GraniteServicesContractorProxy {
	GObject parent_instance;
	GraniteServicesContractorProxyPrivate * priv;
};

struct _GraniteServicesContractorProxyClass {
	GObjectClass parent_class;
};

struct _GraniteServicesSettingsSerializableIface {
	GTypeInterface parent_iface;
	gchar* (*settings_serialize) (GraniteServicesSettingsSerializable* self);
	void (*settings_deserialize) (GraniteServicesSettingsSerializable* self, const gchar* s);
};

struct _GraniteServicesSystem {
	GObject parent_instance;
	GraniteServicesSystemPrivate * priv;
};

struct _GraniteServicesSystemClass {
	GObjectClass parent_class;
};

struct _GraniteSettingsPage {
	GtkBox parent_instance;
	gchar* _icon_name;
	gchar* _title;
	GraniteSettingsPagePrivate * priv;
};

struct _GraniteSettingsPageClass {
	GtkBoxClass parent_class;
};

struct _GraniteSimpleSettingsPage {
	GraniteSettingsPage parent_instance;
	GraniteSimpleSettingsPagePrivate * priv;
};

struct _GraniteSimpleSettingsPageClass {
	GraniteSettingsPageClass parent_class;
};

struct _GraniteAccelLabel {
	GtkBox parent_instance;
	GraniteAccelLabelPrivate * priv;
};

struct _GraniteAccelLabelClass {
	GtkBoxClass parent_class;
};

struct _GraniteBackButton {
	GtkButton parent_instance;
	GraniteBackButtonPrivate * priv;
};

struct _GraniteBackButtonClass {
	GtkButtonClass parent_class;
};

struct _GraniteBin {
	GtkWidget parent_instance;
	GraniteBinPrivate * priv;
};

struct _GraniteBinClass {
	GtkWidgetClass parent_class;
};

struct _GraniteBox {
	GtkBox parent_instance;
	GraniteBoxPrivate * priv;
};

struct _GraniteBoxClass {
	GtkBoxClass parent_class;
};

struct _GraniteDatePicker {
	GtkEntry parent_instance;
	GraniteDatePickerPrivate * priv;
};

struct _GraniteDatePickerClass {
	GtkEntryClass parent_class;
};

struct _GraniteDialog {
	GtkDialog parent_instance;
	GraniteDialogPrivate * priv;
};

struct _GraniteDialogClass {
	GtkDialogClass parent_class;
};

struct _GraniteHeaderLabel {
	GtkWidget parent_instance;
	GraniteHeaderLabelPrivate * priv;
};

struct _GraniteHeaderLabelClass {
	GtkWidgetClass parent_class;
};

struct _GraniteHyperTextView {
	GtkTextView parent_instance;
	GraniteHyperTextViewPrivate * priv;
};

struct _GraniteHyperTextViewClass {
	GtkTextViewClass parent_class;
};

struct _GraniteListItem {
	GtkWidget parent_instance;
	GraniteListItemPrivate * priv;
};

struct _GraniteListItemClass {
	GtkWidgetClass parent_class;
};

struct _GraniteMessageDialog {
	GraniteDialog parent_instance;
	GraniteMessageDialogPrivate * priv;
};

struct _GraniteMessageDialogClass {
	GraniteDialogClass parent_class;
};

struct _GraniteModeSwitch {
	GtkBox parent_instance;
	GraniteModeSwitchPrivate * priv;
};

struct _GraniteModeSwitchClass {
	GtkBoxClass parent_class;
};

struct _GraniteOverlayBar {
	GtkWidget parent_instance;
	GraniteOverlayBarPrivate * priv;
};

struct _GraniteOverlayBarClass {
	GtkWidgetClass parent_class;
};

struct _GranitePlaceholder {
	GtkWidget parent_instance;
	GranitePlaceholderPrivate * priv;
};

struct _GranitePlaceholderClass {
	GtkWidgetClass parent_class;
};

struct _GraniteSettingsSidebar {
	GtkWidget parent_instance;
	GraniteSettingsSidebarPrivate * priv;
};

struct _GraniteSettingsSidebarClass {
	GtkWidgetClass parent_class;
};

struct _GraniteSettings {
	GObject parent_instance;
	GraniteSettingsPrivate * priv;
};

struct _GraniteSettingsClass {
	GObjectClass parent_class;
};

struct _GraniteSwitchModelButton {
	GtkToggleButton parent_instance;
	GraniteSwitchModelButtonPrivate * priv;
};

struct _GraniteSwitchModelButtonClass {
	GtkToggleButtonClass parent_class;
};

struct _GraniteTimePicker {
	GtkEntry parent_instance;
	GraniteTimePickerPrivate * priv;
};

struct _GraniteTimePickerClass {
	GtkEntryClass parent_class;
};

struct _GraniteToolBox {
	GtkWidget parent_instance;
	GraniteToolBoxPrivate * priv;
};

struct _GraniteToolBoxClass {
	GtkWidgetClass parent_class;
};

struct _GraniteToast {
	GtkWidget parent_instance;
	GraniteToastPrivate * priv;
};

struct _GraniteToastClass {
	GtkWidgetClass parent_class;
};

struct _GraniteValidatedEntry {
	GtkEntry parent_instance;
	GraniteValidatedEntryPrivate * priv;
};

struct _GraniteValidatedEntryClass {
	GtkEntryClass parent_class;
};

VALA_EXTERN gchar* granite_date_time_get_default_time_format (gboolean is_12h,
                                                  gboolean with_second);
VALA_EXTERN gchar* granite_date_time_get_relative_datetime (GDateTime* date_time);
VALA_EXTERN gboolean granite_date_time_is_same_day (GDateTime* day1,
                                        GDateTime* day2);
VALA_EXTERN gchar* granite_date_time_get_default_date_format (gboolean with_weekday,
                                                  gboolean with_day,
                                                  gboolean with_year);
VALA_EXTERN gchar* granite_date_time_seconds_to_time (gint seconds);
VALA_EXTERN void granite_init (void);
VALA_EXTERN GType granite_style_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteStyleManager, g_object_unref)
VALA_EXTERN GraniteStyleManager* granite_style_manager_get_default (void);
VALA_EXTERN GraniteStyleManager* granite_style_manager_get_for_display (GdkDisplay* display);
VALA_EXTERN GType granite_settings_color_scheme_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GraniteSettingsColorScheme granite_style_manager_get_color_scheme (GraniteStyleManager* self);
VALA_EXTERN void granite_style_manager_set_color_scheme (GraniteStyleManager* self,
                                             GraniteSettingsColorScheme value);
VALA_EXTERN GdkDisplay* granite_style_manager_get_display (GraniteStyleManager* self);
VALA_EXTERN void granite_services_application_set_badge (gint64 count,
                                             GAsyncReadyCallback _callback_,
                                             gpointer _user_data_);
VALA_EXTERN gboolean granite_services_application_set_badge_finish (GAsyncResult* _res_,
                                                        GError** error);
VALA_EXTERN void granite_services_application_set_badge_visible (gboolean visible,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN gboolean granite_services_application_set_badge_visible_finish (GAsyncResult* _res_,
                                                                GError** error);
VALA_EXTERN void granite_services_application_set_progress (gdouble progress,
                                                GAsyncReadyCallback _callback_,
                                                gpointer _user_data_);
VALA_EXTERN gboolean granite_services_application_set_progress_finish (GAsyncResult* _res_,
                                                           GError** error);
VALA_EXTERN void granite_services_application_set_progress_visible (gboolean visible,
                                                        GAsyncReadyCallback _callback_,
                                                        gpointer _user_data_);
VALA_EXTERN gboolean granite_services_application_set_progress_visible_finish (GAsyncResult* _res_,
                                                                   GError** error);
VALA_EXTERN GType granite_services_contract_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteServicesContract, g_object_unref)
VALA_EXTERN gchar* granite_services_contract_get_display_name (GraniteServicesContract* self);
VALA_EXTERN gchar* granite_services_contract_get_description (GraniteServicesContract* self);
VALA_EXTERN GIcon* granite_services_contract_get_icon (GraniteServicesContract* self);
VALA_EXTERN void granite_services_contract_execute_with_file (GraniteServicesContract* self,
                                                  GFile* file,
                                                  GError** error);
VALA_EXTERN void granite_services_contract_execute_with_files (GraniteServicesContract* self,
                                                   GFile** files,
                                                   gint files_length1,
                                                   GError** error);
VALA_EXTERN GQuark granite_services_contractor_error_quark (void);
VALA_EXTERN GType granite_services_contractor_error_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType granite_services_contractor_proxy_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteServicesContractorProxy, g_object_unref)
VALA_EXTERN GraniteServicesContractorProxy* granite_services_contractor_proxy_get_instance (GError** error);
VALA_EXTERN GeeList* granite_services_contractor_proxy_get_all_contracts (GError** error);
VALA_EXTERN GeeList* granite_services_contractor_proxy_get_contracts_by_mime (const gchar* mime_type,
                                                                  GError** error);
VALA_EXTERN GeeList* granite_services_contractor_proxy_get_contracts_by_mimelist (gchar** mime_types,
                                                                      gint mime_types_length1,
                                                                      GError** error);
VALA_EXTERN GeeList* granite_services_contractor_proxy_get_contracts_for_file (GFile* file,
                                                                   GError** error);
VALA_EXTERN GeeList* granite_services_contractor_proxy_get_contracts_for_files (GFile** files,
                                                                    gint files_length1,
                                                                    GError** error);
VALA_EXTERN GType granite_services_settings_serializable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteServicesSettingsSerializable, g_object_unref)
VALA_EXTERN gchar* granite_services_settings_serializable_settings_serialize (GraniteServicesSettingsSerializable* self);
VALA_EXTERN void granite_services_settings_serializable_settings_deserialize (GraniteServicesSettingsSerializable* self,
                                                                  const gchar* s);
VALA_EXTERN GType granite_services_system_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteServicesSystem, g_object_unref)
VALA_EXTERN gboolean granite_services_system_history_is_enabled (void);
VALA_EXTERN GraniteServicesSystem* granite_services_system_new (void);
VALA_EXTERN GraniteServicesSystem* granite_services_system_construct (GType object_type);
VALA_EXTERN GType granite_settings_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteSettingsPage, g_object_unref)
VALA_EXTERN GType granite_settings_page_status_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GraniteSettingsPageStatusType granite_settings_page_get_status_type (GraniteSettingsPage* self);
VALA_EXTERN void granite_settings_page_set_status_type (GraniteSettingsPage* self,
                                            GraniteSettingsPageStatusType value);
VALA_EXTERN GtkWidget* granite_settings_page_get_display_widget (GraniteSettingsPage* self);
VALA_EXTERN const gchar* granite_settings_page_get_header (GraniteSettingsPage* self);
VALA_EXTERN const gchar* granite_settings_page_get_status (GraniteSettingsPage* self);
VALA_EXTERN void granite_settings_page_set_status (GraniteSettingsPage* self,
                                       const gchar* value);
VALA_EXTERN const gchar* granite_settings_page_get_icon_name (GraniteSettingsPage* self);
VALA_EXTERN void granite_settings_page_set_icon_name (GraniteSettingsPage* self,
                                          const gchar* value);
VALA_EXTERN const gchar* granite_settings_page_get_title (GraniteSettingsPage* self);
VALA_EXTERN void granite_settings_page_set_title (GraniteSettingsPage* self,
                                      const gchar* value);
VALA_EXTERN GtkWidget* granite_settings_page_get_child (GraniteSettingsPage* self);
VALA_EXTERN void granite_settings_page_set_child (GraniteSettingsPage* self,
                                      GtkWidget* value);
VALA_EXTERN GraniteSettingsPage* granite_settings_page_construct (GType object_type);
VALA_EXTERN GType granite_simple_settings_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteSimpleSettingsPage, g_object_unref)
VALA_EXTERN GtkBox* granite_simple_settings_page_get_action_area (GraniteSimpleSettingsPage* self);
VALA_EXTERN GtkGrid* granite_simple_settings_page_get_content_area (GraniteSimpleSettingsPage* self);
VALA_EXTERN GtkSwitch* granite_simple_settings_page_get_status_switch (GraniteSimpleSettingsPage* self);
VALA_EXTERN gboolean granite_simple_settings_page_get_activatable (GraniteSimpleSettingsPage* self);
VALA_EXTERN const gchar* granite_simple_settings_page_get_description (GraniteSimpleSettingsPage* self);
VALA_EXTERN void granite_simple_settings_page_set_description (GraniteSimpleSettingsPage* self,
                                                   const gchar* value);
VALA_EXTERN GraniteSimpleSettingsPage* granite_simple_settings_page_construct (GType object_type);
VALA_EXTERN GType granite_accel_label_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteAccelLabel, g_object_unref)
VALA_EXTERN const gchar* granite_accel_label_get_action_name (GraniteAccelLabel* self);
VALA_EXTERN void granite_accel_label_set_action_name (GraniteAccelLabel* self,
                                          const gchar* value);
VALA_EXTERN const gchar* granite_accel_label_get_accel_string (GraniteAccelLabel* self);
VALA_EXTERN void granite_accel_label_set_accel_string (GraniteAccelLabel* self,
                                           const gchar* value);
VALA_EXTERN const gchar* granite_accel_label_get_label (GraniteAccelLabel* self);
VALA_EXTERN void granite_accel_label_set_label (GraniteAccelLabel* self,
                                    const gchar* value);
VALA_EXTERN GraniteAccelLabel* granite_accel_label_new (const gchar* label,
                                            const gchar* accel_string);
VALA_EXTERN GraniteAccelLabel* granite_accel_label_construct (GType object_type,
                                                  const gchar* label,
                                                  const gchar* accel_string);
VALA_EXTERN GraniteAccelLabel* granite_accel_label_new_from_action_name (const gchar* label,
                                                             const gchar* action_name);
VALA_EXTERN GraniteAccelLabel* granite_accel_label_construct_from_action_name (GType object_type,
                                                                   const gchar* label,
                                                                   const gchar* action_name);
VALA_EXTERN GType granite_back_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteBackButton, g_object_unref)
VALA_EXTERN const gchar* granite_back_button_get_label (GraniteBackButton* self);
VALA_EXTERN void granite_back_button_set_label (GraniteBackButton* self,
                                    const gchar* value);
VALA_EXTERN GraniteBackButton* granite_back_button_new (const gchar* label);
VALA_EXTERN GraniteBackButton* granite_back_button_construct (GType object_type,
                                                  const gchar* label);
VALA_EXTERN GType granite_bin_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteBin, g_object_unref)
VALA_EXTERN GtkWidget* granite_bin_get_child (GraniteBin* self);
VALA_EXTERN void granite_bin_set_child (GraniteBin* self,
                            GtkWidget* value);
VALA_EXTERN GraniteBin* granite_bin_new (void);
VALA_EXTERN GraniteBin* granite_bin_construct (GType object_type);
VALA_EXTERN GType granite_box_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteBox, g_object_unref)
VALA_EXTERN GType granite_box_spacing_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* granite_box_spacing_to_string (GraniteBoxSpacing self);
VALA_EXTERN GraniteBoxSpacing granite_box_get_child_spacing (GraniteBox* self);
VALA_EXTERN void granite_box_set_child_spacing (GraniteBox* self,
                                    GraniteBoxSpacing value);
VALA_EXTERN GraniteBox* granite_box_new (GtkOrientation orientation,
                             GraniteBoxSpacing child_spacing);
VALA_EXTERN GraniteBox* granite_box_construct (GType object_type,
                                   GtkOrientation orientation,
                                   GraniteBoxSpacing child_spacing);
VALA_EXTERN GType granite_date_picker_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteDatePicker, g_object_unref)
VALA_EXTERN const gchar* granite_date_picker_get_format (GraniteDatePicker* self);
VALA_EXTERN GDateTime* granite_date_picker_get_date (GraniteDatePicker* self);
VALA_EXTERN void granite_date_picker_set_date (GraniteDatePicker* self,
                                   GDateTime* value);
VALA_EXTERN GraniteDatePicker* granite_date_picker_new_with_format (const gchar* format);
VALA_EXTERN GraniteDatePicker* granite_date_picker_construct_with_format (GType object_type,
                                                              const gchar* format);
VALA_EXTERN GraniteDatePicker* granite_date_picker_new (void);
VALA_EXTERN GraniteDatePicker* granite_date_picker_construct (GType object_type);
VALA_EXTERN GType granite_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteDialog, g_object_unref)
VALA_EXTERN GraniteDialog* granite_dialog_new (void);
VALA_EXTERN GraniteDialog* granite_dialog_construct (GType object_type);
VALA_EXTERN GtkWidget* granite_dialog_add_button (GraniteDialog* self,
                                      const gchar* button_text,
                                      gint response_id);
VALA_EXTERN GType granite_header_label_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteHeaderLabel, g_object_unref)
VALA_EXTERN GType granite_header_label_size_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* granite_header_label_size_to_string (GraniteHeaderLabelSize self);
VALA_EXTERN const gchar* granite_header_label_get_label (GraniteHeaderLabel* self);
VALA_EXTERN void granite_header_label_set_label (GraniteHeaderLabel* self,
                                     const gchar* value);
VALA_EXTERN GtkWidget* granite_header_label_get_mnemonic_widget (GraniteHeaderLabel* self);
VALA_EXTERN void granite_header_label_set_mnemonic_widget (GraniteHeaderLabel* self,
                                               GtkWidget* value);
VALA_EXTERN GraniteHeaderLabelSize granite_header_label_get_size (GraniteHeaderLabel* self);
VALA_EXTERN void granite_header_label_set_size (GraniteHeaderLabel* self,
                                    GraniteHeaderLabelSize value);
VALA_EXTERN PangoEllipsizeMode granite_header_label_get_ellipsize (GraniteHeaderLabel* self);
VALA_EXTERN void granite_header_label_set_ellipsize (GraniteHeaderLabel* self,
                                         PangoEllipsizeMode value);
VALA_EXTERN const gchar* granite_header_label_get_secondary_text (GraniteHeaderLabel* self);
VALA_EXTERN void granite_header_label_set_secondary_text (GraniteHeaderLabel* self,
                                              const gchar* value);
VALA_EXTERN GraniteHeaderLabel* granite_header_label_new (const gchar* label);
VALA_EXTERN GraniteHeaderLabel* granite_header_label_construct (GType object_type,
                                                    const gchar* label);
VALA_EXTERN GType granite_hyper_text_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteHyperTextView, g_object_unref)
VALA_EXTERN GraniteHyperTextView* granite_hyper_text_view_new (void);
VALA_EXTERN GraniteHyperTextView* granite_hyper_text_view_construct (GType object_type);
VALA_EXTERN GType granite_list_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteListItem, g_object_unref)
VALA_EXTERN const gchar* granite_list_item_get_text (GraniteListItem* self);
VALA_EXTERN void granite_list_item_set_text (GraniteListItem* self,
                                 const gchar* value);
VALA_EXTERN const gchar* granite_list_item_get_description (GraniteListItem* self);
VALA_EXTERN void granite_list_item_set_description (GraniteListItem* self,
                                        const gchar* value);
VALA_EXTERN GtkWidget* granite_list_item_get_child (GraniteListItem* self);
VALA_EXTERN void granite_list_item_set_child (GraniteListItem* self,
                                  GtkWidget* value);
VALA_EXTERN GMenuModel* granite_list_item_get_menu_model (GraniteListItem* self);
VALA_EXTERN void granite_list_item_set_menu_model (GraniteListItem* self,
                                       GMenuModel* value);
VALA_EXTERN GraniteListItem* granite_list_item_new (void);
VALA_EXTERN GraniteListItem* granite_list_item_construct (GType object_type);
VALA_EXTERN GType granite_message_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteMessageDialog, g_object_unref)
VALA_EXTERN const gchar* granite_message_dialog_get_primary_text (GraniteMessageDialog* self);
VALA_EXTERN void granite_message_dialog_set_primary_text (GraniteMessageDialog* self,
                                              const gchar* value);
VALA_EXTERN const gchar* granite_message_dialog_get_secondary_text (GraniteMessageDialog* self);
VALA_EXTERN void granite_message_dialog_set_secondary_text (GraniteMessageDialog* self,
                                                const gchar* value);
VALA_EXTERN GIcon* granite_message_dialog_get_image_icon (GraniteMessageDialog* self);
VALA_EXTERN void granite_message_dialog_set_image_icon (GraniteMessageDialog* self,
                                            GIcon* value);
VALA_EXTERN GIcon* granite_message_dialog_get_badge_icon (GraniteMessageDialog* self);
VALA_EXTERN void granite_message_dialog_set_badge_icon (GraniteMessageDialog* self,
                                            GIcon* value);
VALA_EXTERN GtkLabel* granite_message_dialog_get_primary_label (GraniteMessageDialog* self);
VALA_EXTERN GtkLabel* granite_message_dialog_get_secondary_label (GraniteMessageDialog* self);
VALA_EXTERN GtkBox* granite_message_dialog_get_custom_bin (GraniteMessageDialog* self);
VALA_EXTERN GraniteMessageDialog* granite_message_dialog_new (const gchar* primary_text,
                                                  const gchar* secondary_text,
                                                  GIcon* image_icon,
                                                  GtkButtonsType buttons);
VALA_EXTERN GraniteMessageDialog* granite_message_dialog_construct (GType object_type,
                                                        const gchar* primary_text,
                                                        const gchar* secondary_text,
                                                        GIcon* image_icon,
                                                        GtkButtonsType buttons);
VALA_EXTERN GraniteMessageDialog* granite_message_dialog_new_with_image_from_icon_name (const gchar* primary_text,
                                                                            const gchar* secondary_text,
                                                                            const gchar* image_icon_name,
                                                                            GtkButtonsType buttons);
VALA_EXTERN GraniteMessageDialog* granite_message_dialog_construct_with_image_from_icon_name (GType object_type,
                                                                                  const gchar* primary_text,
                                                                                  const gchar* secondary_text,
                                                                                  const gchar* image_icon_name,
                                                                                  GtkButtonsType buttons);
VALA_EXTERN void granite_message_dialog_show_error_details (GraniteMessageDialog* self,
                                                const gchar* error_message);
VALA_EXTERN GType granite_mode_switch_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteModeSwitch, g_object_unref)
VALA_EXTERN gboolean granite_mode_switch_get_active (GraniteModeSwitch* self);
VALA_EXTERN void granite_mode_switch_set_active (GraniteModeSwitch* self,
                                     gboolean value);
VALA_EXTERN GIcon* granite_mode_switch_get_primary_icon_gicon (GraniteModeSwitch* self);
VALA_EXTERN void granite_mode_switch_set_primary_icon_gicon (GraniteModeSwitch* self,
                                                 GIcon* value);
VALA_EXTERN const gchar* granite_mode_switch_get_primary_icon_name (GraniteModeSwitch* self);
VALA_EXTERN void granite_mode_switch_set_primary_icon_name (GraniteModeSwitch* self,
                                                const gchar* value);
VALA_EXTERN const gchar* granite_mode_switch_get_primary_icon_tooltip_text (GraniteModeSwitch* self);
VALA_EXTERN void granite_mode_switch_set_primary_icon_tooltip_text (GraniteModeSwitch* self,
                                                        const gchar* value);
VALA_EXTERN GIcon* granite_mode_switch_get_secondary_icon_gicon (GraniteModeSwitch* self);
VALA_EXTERN void granite_mode_switch_set_secondary_icon_gicon (GraniteModeSwitch* self,
                                                   GIcon* value);
VALA_EXTERN const gchar* granite_mode_switch_get_secondary_icon_name (GraniteModeSwitch* self);
VALA_EXTERN void granite_mode_switch_set_secondary_icon_name (GraniteModeSwitch* self,
                                                  const gchar* value);
VALA_EXTERN const gchar* granite_mode_switch_get_secondary_icon_tooltip_text (GraniteModeSwitch* self);
VALA_EXTERN void granite_mode_switch_set_secondary_icon_tooltip_text (GraniteModeSwitch* self,
                                                          const gchar* value);
VALA_EXTERN GraniteModeSwitch* granite_mode_switch_new (GIcon* primary_icon_gicon,
                                            GIcon* secondary_icon_gicon);
VALA_EXTERN GraniteModeSwitch* granite_mode_switch_construct (GType object_type,
                                                  GIcon* primary_icon_gicon,
                                                  GIcon* secondary_icon_gicon);
VALA_EXTERN GraniteModeSwitch* granite_mode_switch_new_from_icon_name (const gchar* primary_icon_name,
                                                           const gchar* secondary_icon_name);
VALA_EXTERN GraniteModeSwitch* granite_mode_switch_construct_from_icon_name (GType object_type,
                                                                 const gchar* primary_icon_name,
                                                                 const gchar* secondary_icon_name);
VALA_EXTERN GType granite_overlay_bar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteOverlayBar, g_object_unref)
VALA_EXTERN GtkOverlay* granite_overlay_bar_get_overlay (GraniteOverlayBar* self);
VALA_EXTERN const gchar* granite_overlay_bar_get_label (GraniteOverlayBar* self);
VALA_EXTERN void granite_overlay_bar_set_label (GraniteOverlayBar* self,
                                    const gchar* value);
VALA_EXTERN gboolean granite_overlay_bar_get_active (GraniteOverlayBar* self);
VALA_EXTERN void granite_overlay_bar_set_active (GraniteOverlayBar* self,
                                     gboolean value);
VALA_EXTERN GraniteOverlayBar* granite_overlay_bar_new (GtkOverlay* overlay);
VALA_EXTERN GraniteOverlayBar* granite_overlay_bar_construct (GType object_type,
                                                  GtkOverlay* overlay);
VALA_EXTERN GType granite_placeholder_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GranitePlaceholder, g_object_unref)
VALA_EXTERN const gchar* granite_placeholder_get_title (GranitePlaceholder* self);
VALA_EXTERN void granite_placeholder_set_title (GranitePlaceholder* self,
                                    const gchar* value);
VALA_EXTERN const gchar* granite_placeholder_get_description (GranitePlaceholder* self);
VALA_EXTERN void granite_placeholder_set_description (GranitePlaceholder* self,
                                          const gchar* value);
VALA_EXTERN GIcon* granite_placeholder_get_icon (GranitePlaceholder* self);
VALA_EXTERN void granite_placeholder_set_icon (GranitePlaceholder* self,
                                   GIcon* value);
VALA_EXTERN GranitePlaceholder* granite_placeholder_new (const gchar* title);
VALA_EXTERN GranitePlaceholder* granite_placeholder_construct (GType object_type,
                                                   const gchar* title);
VALA_EXTERN GtkButton* granite_placeholder_append_button (GranitePlaceholder* self,
                                              GIcon* icon,
                                              const gchar* label,
                                              const gchar* description);
VALA_EXTERN GType granite_settings_sidebar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteSettingsSidebar, g_object_unref)
VALA_EXTERN GtkStack* granite_settings_sidebar_get_stack (GraniteSettingsSidebar* self);
VALA_EXTERN const gchar* granite_settings_sidebar_get_visible_child_name (GraniteSettingsSidebar* self);
VALA_EXTERN void granite_settings_sidebar_set_visible_child_name (GraniteSettingsSidebar* self,
                                                      const gchar* value);
VALA_EXTERN GraniteSettingsSidebar* granite_settings_sidebar_new (GtkStack* stack);
VALA_EXTERN GraniteSettingsSidebar* granite_settings_sidebar_construct (GType object_type,
                                                            GtkStack* stack);
VALA_EXTERN GType granite_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteSettings, g_object_unref)
VALA_EXTERN void granite_settings_get_accent_color (GraniteSettings* self,
                                        GdkRGBA * result);
VALA_EXTERN GraniteSettingsColorScheme granite_settings_get_prefers_color_scheme (GraniteSettings* self);
VALA_EXTERN GraniteSettings* granite_settings_get_default (void);
VALA_EXTERN GType granite_switch_model_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteSwitchModelButton, g_object_unref)
VALA_EXTERN const gchar* granite_switch_model_button_get_text (GraniteSwitchModelButton* self);
VALA_EXTERN void granite_switch_model_button_set_text (GraniteSwitchModelButton* self,
                                           const gchar* value);
VALA_EXTERN const gchar* granite_switch_model_button_get_description (GraniteSwitchModelButton* self);
VALA_EXTERN void granite_switch_model_button_set_description (GraniteSwitchModelButton* self,
                                                  const gchar* value);
VALA_EXTERN GraniteSwitchModelButton* granite_switch_model_button_new (const gchar* text);
VALA_EXTERN GraniteSwitchModelButton* granite_switch_model_button_construct (GType object_type,
                                                                 const gchar* text);
VALA_EXTERN GType granite_time_picker_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteTimePicker, g_object_unref)
VALA_EXTERN const gchar* granite_time_picker_get_format_12 (GraniteTimePicker* self);
VALA_EXTERN const gchar* granite_time_picker_get_format_24 (GraniteTimePicker* self);
VALA_EXTERN GDateTime* granite_time_picker_get_time (GraniteTimePicker* self);
VALA_EXTERN void granite_time_picker_set_time (GraniteTimePicker* self,
                                   GDateTime* value);
VALA_EXTERN GraniteTimePicker* granite_time_picker_new_with_format (const gchar* format_12,
                                                        const gchar* format_24);
VALA_EXTERN GraniteTimePicker* granite_time_picker_construct_with_format (GType object_type,
                                                              const gchar* format_12,
                                                              const gchar* format_24);
VALA_EXTERN GraniteTimePicker* granite_time_picker_new (void);
VALA_EXTERN GraniteTimePicker* granite_time_picker_construct (GType object_type);
VALA_EXTERN GType granite_tool_box_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteToolBox, g_object_unref)
VALA_EXTERN GtkWidget* granite_tool_box_get_content (GraniteToolBox* self);
VALA_EXTERN void granite_tool_box_set_content (GraniteToolBox* self,
                                   GtkWidget* value);
VALA_EXTERN void granite_tool_box_add_top_bar (GraniteToolBox* self,
                                   GtkWidget* widget);
VALA_EXTERN void granite_tool_box_add_bottom_bar (GraniteToolBox* self,
                                      GtkWidget* widget);
VALA_EXTERN void granite_tool_box_remove (GraniteToolBox* self,
                              GtkWidget* widget);
VALA_EXTERN GraniteToolBox* granite_tool_box_new (void);
VALA_EXTERN GraniteToolBox* granite_tool_box_construct (GType object_type);
VALA_EXTERN GType granite_toast_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteToast, g_object_unref)
VALA_EXTERN GType granite_toast_dismiss_reason_get_type (void) G_GNUC_CONST ;
VALA_EXTERN const gchar* granite_toast_get_title (GraniteToast* self);
VALA_EXTERN void granite_toast_set_title (GraniteToast* self,
                              const gchar* value);
VALA_EXTERN GraniteToast* granite_toast_new (const gchar* title);
VALA_EXTERN GraniteToast* granite_toast_construct (GType object_type,
                                       const gchar* title);
VALA_EXTERN void granite_toast_set_default_action (GraniteToast* self,
                                       const gchar* label);
VALA_EXTERN void granite_toast_send_notification (GraniteToast* self);
VALA_EXTERN void granite_toast_withdraw (GraniteToast* self);
VALA_EXTERN gchar* granite_accel_to_string (const gchar* accel);
VALA_EXTERN gchar* granite_markup_accel_tooltip (gchar** accels,
                                     gint accels_length1,
                                     const gchar* description);
VALA_EXTERN void granite_contrasting_foreground_color (GdkRGBA* bg_color,
                                           GdkRGBA* result);
VALA_EXTERN GtkCssProvider* granite_widgets_utils_set_color_primary (GtkWidget* window,
                                                         GdkRGBA* color,
                                                         gint priority) G_GNUC_DEPRECATED ;
VALA_EXTERN GType granite_validated_entry_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteValidatedEntry, g_object_unref)
VALA_EXTERN gboolean granite_validated_entry_get_is_valid (GraniteValidatedEntry* self);
VALA_EXTERN void granite_validated_entry_set_is_valid (GraniteValidatedEntry* self,
                                           gboolean value);
VALA_EXTERN gint granite_validated_entry_get_min_length (GraniteValidatedEntry* self);
VALA_EXTERN void granite_validated_entry_set_min_length (GraniteValidatedEntry* self,
                                             gint value);
VALA_EXTERN GRegex* granite_validated_entry_get_regex (GraniteValidatedEntry* self);
VALA_EXTERN void granite_validated_entry_set_regex (GraniteValidatedEntry* self,
                                        GRegex* value);
VALA_EXTERN GraniteValidatedEntry* granite_validated_entry_new_from_regex (GRegex* regex_arg);
VALA_EXTERN GraniteValidatedEntry* granite_validated_entry_construct_from_regex (GType object_type,
                                                                     GRegex* regex_arg);
VALA_EXTERN GraniteValidatedEntry* granite_validated_entry_new (void);
VALA_EXTERN GraniteValidatedEntry* granite_validated_entry_construct (GType object_type);

G_END_DECLS

#endif
